netapp_ontap.models.storage_bridge_fc_ports_sfp API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.storage_bridge_fc_ports_sfp`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class StorageBridgeFcPortsSfpSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the StorageBridgeFcPortsSfp object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `data_rate_capability: float GET POST PATCH`

    Bridge FC port SFP data rate capability, in Gbps

  `part_number: str GET POST PATCH`

    The part_number field of the storage_bridge_fc_ports_sfp.

  `serial_number: str GET POST PATCH`

    Bridge FC port SFP serial number

  `vendor: str GET POST PATCH`

    Bridge FC port SFP vendor